aboutsummaryrefslogtreecommitdiffstats
path: root/examples/widgets/layouts/dynamiclayouts.py
diff options
context:
space:
mode:
Diffstat (limited to 'examples/widgets/layouts/dynamiclayouts.py')
-rw-r--r--examples/widgets/layouts/dynamiclayouts.py6
1 files changed, 3 insertions, 3 deletions
diff --git a/examples/widgets/layouts/dynamiclayouts.py b/examples/widgets/layouts/dynamiclayouts.py
index 5ae7113ee..5d2f2babe 100644
--- a/examples/widgets/layouts/dynamiclayouts.py
+++ b/examples/widgets/layouts/dynamiclayouts.py
@@ -40,10 +40,10 @@
##
#############################################################################
-"""PySide2 port of the widgets/layouts/dynamiclayouts example from Qt v5.x"""
+"""PySide6 port of the widgets/layouts/dynamiclayouts example from Qt v5.x"""
-from PySide2.QtCore import Qt, QSize
-from PySide2.QtWidgets import (QApplication, QDialog, QLayout, QGridLayout,
+from PySide6.QtCore import Qt, QSize
+from PySide6.QtWidgets import (QApplication, QDialog, QLayout, QGridLayout,
QMessageBox, QGroupBox, QSpinBox, QSlider,
QProgressBar, QDial, QDialogButtonBox,
QComboBox, QLabel)